@@ -127,8 +127,6 @@ class CLIParser:
             for module in [
                 "boost",
                 "resize",
-                "create",
-                "remove",
                 "cloudwizard",
                 "follow",
             ]
@@ -518,6 +516,12 @@ class CLIParser:
                 required=False,
                 help="list compute instances",
             )
+            parser.add_argument(
+                "--public-ips-only",
+                action="store_true",
+                required=False,
+                help="when used with '--instances', lists public IP addresses only",
+            )
             parser.add_argument(
                 "--allowances",
                 "-A",
@@ -525,6 +529,13 @@ class CLIParser:
                 required=False,
                 help="list allowances",
             )
+            parser.add_argument(
+                "--attribute-definitions",
+                "-R",
+                action="store_true",
+                required=False,
+                help="list attribute definitions",
+            )
 
         if any(module in sys.argv[0] for module in ["upload"]):
             parser.add_argument(
@@ -1306,6 +1317,11 @@ class CLIParser:
     def allowances(self) -> Optional[bool]:
         return self.args.allowances
 
+    @property
+    @allow_missing_attribute
+    def attribute_definitions(self) -> Optional[bool]:
+        return self.args.attribute_definitions
+
     @property
     @allow_missing_attribute
     def show_keyring_passwords(self) -> Optional[bool]:
@@ -1421,6 +1437,11 @@ class CLIParser:
     def match_allowances_by_description(self) -> Optional[bool]:
         return self.args.match_allowances_by_description
 
+    @property
+    @allow_missing_attribute
+    def public_ips_only(self) -> Optional[bool]:
+        return self.args.public_ips_only
+
 
 def lookup_module_description(module_name: str) -> Optional[str]:
     """
